/*
 * @(#)Netbeat.java 1.1  2000/04/30
 *
 * Author: Andreas Dangel
 *
 * Copyright (c) 2000 Andreas Dangel
 *
 */

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Font;
import java.awt.FontMetrics;
import java.util.Date;

/**
 * Das Applet Netbeat gibt das Datum, den Netbeat und die Uhrzeit aus.
 * Folgendes Format wird benutzt:
 * <p>
 * <br>dd.mm.yyyy@netbeat
 * <br>hh:mm:ss timezone
 * <p>
 * @param fontName  - Optionaler Parameter, der die Java-spezifische Schriftart
 *                    festlegt; default Courier.
 * @param fontStyle - Optionaler Parameter; PLAIN (default), BOLD, ITALIC oder
 *                    &quot;BOLD + ITALIC&quot;.
 * @param fontSize  - Optionaler Parameter, der die Schriftgr&ouml;&szlig;e in
 *                    pt (Punkt) angibt; default 10pt.
 * @param fontColor - Optionaler Parameter, der die Farbe der Schrift
 *                    festlegt; default &quot;black&quot;.
 * @param backgroundColor - Optionaler Parameter, der die Farbe des
 *                    Applethintergrundes festlegt; default
 *                    &quot;white&quot;.
 * <p>
 * @version 1.1
 * @date 2000/04/30
 * @author Andreas Dangel
 */
public class Netbeat extends java.applet.Applet
    implements Runnable {

    Font  theFont;
    int   fontHeight;
    Color colFontColor;
    Color colBackgroundColor;
    Date theDate;
    Thread runner;

    String getFontName() {
        String fontName  = getParameter("fontName");

        if (fontName == null) {
            fontName = "Courier";
        }
        fontName = fontName.toUpperCase();
        if (fontName.equals("HELVETICA")) {
            fontName = "Helvetica";
        } else if (fontName.equals("TIMESROMAN")) {
            fontName = "TimesRoman";
        } else if (fontName.equals("COURIER")) {
            fontName = "Courier";
        } else if (fontName.equals("DIALOG")) {
            fontName = "Dialog";
        } else if (fontName.equals("DIALOGINPUT")) {
            fontName = "DialogInput";
        } else if (fontName.equals("ZAPFDINGBATS")) {
            fontName = "ZapfDingbats";
        } else if (fontName.equals("DEFAULT")) {
            fontName = "default";
        } else {
            fontName = "Courier";
        }

        return fontName;
    }

    int getFontStyle() {
        String fontStyle = getParameter("fontStyle");
        int iFontStyle;

        if (fontStyle == null) {
            fontStyle = "PLAIN";
        }
        fontStyle = fontStyle.toUpperCase();
        if (fontStyle.equals("PLAIN")) {
            iFontStyle = Font.PLAIN;
        } else if (fontStyle.equals("BOLD")) {
            iFontStyle = Font.BOLD;
        } else if (fontStyle.equals("ITALIC")) {
            iFontStyle = Font.ITALIC;
        } else if (fontStyle.equals("BOLD + ITALIC")) {
            iFontStyle = Font.BOLD + Font.ITALIC;
        } else {
            iFontStyle = Font.PLAIN;
        }

        return iFontStyle;
    }

    int getFontSize() {
        String fontSize  = getParameter("fontSize");
        int iFontSize;

        if (fontSize != null) {
            try {
                iFontSize = Integer.parseInt(fontSize);
            } catch (NumberFormatException e) {
                iFontSize = 10;
            }
        } else {
            iFontSize = 10;
        }

        return iFontSize;
    }
 
    Color getFontColor() {
        String fontColor = getParameter("fontColor");
        Color col;

        if (fontColor == null) {
            fontColor = "black";
        }

        fontColor = fontColor.toUpperCase();

        if (fontColor.equals("BLACK")) {
            col = Color.black;
        } else if (fontColor.equals("BLUE")) {
            col = Color.blue;
        } else if (fontColor.equals("CYAN")) {
            col = Color.cyan;
        } else if (fontColor.equals("DARKGRAY")) {
            col = Color.darkGray;
        } else if (fontColor.equals("GRAY")) {
            col = Color.gray;
        } else if (fontColor.equals("GREEN")) {
            col = Color.green;
        } else if (fontColor.equals("LIGHTGRAY")) {
            col = Color.lightGray;
        } else if (fontColor.equals("MAGENTA")) {
            col = Color.magenta;
        } else if (fontColor.equals("ORANGE")) {
            col = Color.orange;
        } else if (fontColor.equals("PINK")) {
            col = Color.pink;
        } else if (fontColor.equals("RED")) {
            col = Color.red;
        } else if (fontColor.equals("WHITE")) {
            col = Color.white;
        } else if (fontColor.equals("YELLOW")) {
            col = Color.yellow;
        } else {
            col = Color.black;
        }

        return col;        
    }

    Color getBackgroundColor() {
        String backgroundColor = getParameter("backgroundColor");
        Color col;

        if (backgroundColor == null) {
            backgroundColor = "white";
        }

        backgroundColor = backgroundColor.toUpperCase();

        if (backgroundColor.equals("BLACK")) {
            col = Color.black;
        } else if (backgroundColor.equals("BLUE")) {
            col = Color.blue;
        } else if (backgroundColor.equals("CYAN")) {
            col = Color.cyan;
        } else if (backgroundColor.equals("DARKGRAY")) {
            col = Color.darkGray;
        } else if (backgroundColor.equals("GRAY")) {
            col = Color.gray;
        } else if (backgroundColor.equals("GREEN")) {
            col = Color.green;
        } else if (backgroundColor.equals("LIGTHGRAY")) {
            col = Color.lightGray;
        } else if (backgroundColor.equals("MAGENTA")) {
            col = Color.magenta;
        } else if (backgroundColor.equals("ORANGE")) {
            col = Color.orange;
        } else if (backgroundColor.equals("PINK")) {
            col = Color.pink;
        } else if (backgroundColor.equals("RED")) {
            col = Color.red;
        } else if (backgroundColor.equals("WHITE")) {
            col = Color.white;
        } else if (backgroundColor.equals("YELLOW")) {
            col = Color.yellow;
        } else {
            col = Color.white;
        }

        return col;
    }

    public void init() {
        theFont = new Font(getFontName(), getFontStyle(),
                           getFontSize()); 
        fontHeight = getFontSize();
        colFontColor = getFontColor();
        colBackgroundColor = getBackgroundColor();
    }

    public void start() {
        if (runner == null) {
            runner = new Thread(this);
            runner.start();
        }
    }

    public void stop() {
        if (runner != null) {
            runner = null;
        }
    }

    public void run() {
        Thread thisThread = Thread.currentThread();
        while (runner == thisThread) {
            repaint();
            try {
                Thread.sleep(1000);
            } catch (InterruptedException e) { }
        }
    }

    public void paint(Graphics screen) {
        FontMetrics fm = getFontMetrics(theFont);
        String line;
        int x;
        int y;
        
        theDate = new Date();

        screen.setFont(theFont);
        setForeground(colFontColor);
        setBackground(colBackgroundColor);

        line = getDateString() + getNetbeat();
        x = (size().width - fm.stringWidth(line)) / 2;
        y = fontHeight;

        screen.drawString(line , x, y);

        line = getTimeString() + " " + getTimeZone();
        x = (size().width - fm.stringWidth(line)) / 2;
        y += fontHeight;

        screen.drawString(line, x, y);
    }

    String getDateString() {
        String ret;
        ret = leadingZero(theDate.getDate())
            + "." + leadingZero(theDate.getMonth() + 1)
            + "." + leadingZero(theDate.getYear() + 1900);
        return ret;
    }

    String getNetbeat() {
        float hours = 0F;
        int beat = 0;

        hours += (float) theDate.getHours();
        hours += (float) theDate.getMinutes() / 60;
        hours += (float) theDate.getSeconds() / 3600;
        hours += (float) theDate.getTimezoneOffset() / 60;
        hours += 1F;

        beat = Math.round(hours * 1000 / 24);

        if (beat < 0) {
            beat += 1000;
        }
        
        if (beat < 10) {
            return "@00" + beat;
        } else if (beat < 100) {
            return "@0" + beat;
        } else {
            return "@" + beat;
        }
    }

    String getTimeString() {
        String ret;
        ret = leadingZero(theDate.getHours())
            + ":" + leadingZero(theDate.getMinutes())
            + ":" + leadingZero(theDate.getSeconds());
        return ret;
    }

    String getTimeZone() {
        if (theDate.getTimezoneOffset() == -60) {
            return "MEZ";
        } else if (theDate.getTimezoneOffset() == -120) {
            return "MESZ";
        } else {
            return "" + theDate.getTimezoneOffset();
        }
    }

    String leadingZero(int value) {
        if (value < 10) {
            return "0" + value;
        } else {
            return "" + value;
        }
    }
}
